function ZET.Build.Interface()
	local Gsub, Match, String, Upper, Pairs = string.gsub, string.match, string.format, string.upper, pairs
	local Register = Command.Event.Attach
	local Context, Frame = UI.CreateContext, UI.CreateFrame
	local I, G, E =  ZET.Interface, ZET.Globals, ZET
	
	if ZET_Global then
		G = ZET_Global
	else
		ZET_Global = G
	end

	I.Main = Context("Main")

	I.Title = Frame("Text", "Title", I.Main)
	I.Event = Frame("Text", "Event", I.Main)
	I.Options = Frame("Texture", "Options", I.Main)
	I.Options.Window = Frame("RiftWindow", "OptionsWindow", I.Main)
	
	I.Options.Window.Font = Frame("Text", "FontSlider", I.Options.Window)
	I.Options.Window.FontBG = Frame("Text", "FontBGSlider", I.Options.Window)
	I.Options.Window.FontSize = Frame("Text", "FontSizeSlider", I.Options.Window)
	I.Options.Window.Alpha = Frame("Text", "Alpha", I.Options.Window)
	I.Options.Window.Clear = Frame("RiftButton", "Clear", I.Options.Window)
	I.Options.Window.Close = Frame("RiftButton", "Close", I.Options.Window)
	I.Options.Window.Force = Frame("RiftButton", "Force", I.Options.Window)
	
	I.Options.Window.SliderFont = Frame("RiftSlider", "SliderFont", I.Options.Window)
	I.Options.Window.SliderBG = Frame("RiftSlider", "SliderBG", I.Options.Window)
	I.Options.Window.SliderSize = Frame("RiftSlider", "SliderSize", I.Options.Window)
	I.Options.Window.SliderAlpha = Frame("RiftSlider", "SliderAlpha", I.Options.Window)
	
	I.Title:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
	I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
	I.Title:SetFontSize(G.FontSize)
	I.Title:SetPoint("CENTER", UIParent, "CENTER", G.MainX, G.MainY)
	I.Title:SetText(ZET.Translation.zoneeventtracker[E.Lang])
	
	I.Event:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
	I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
	I.Event:SetFontSize(G.FontSize)
	I.Event:SetVisible(false)
	I.Event:SetPoint("TOPLEFT", I.Title, "BOTTOMLEFT", 0, 0)
	
	I.Options:SetPoint("CENTER", UIParent, "CENTER", G.IconX, G.IconY)
	I.Options:SetTexture("ZET", "png/options.png")
	I.Options:SetVisible(true)
	
	I.Options.Window:SetTitle("ZET " .. ZET.Translation.options[E.Lang])
	I.Options.Window:SetHeight(400)
	I.Options.Window:SetWidth(300)
	I.Options.Window:SetPoint("CENTER", UIParent, "CENTER", G.WindowX, G.WindowY)
	I.Options.Window:SetVisible(false)
	
	I.Options.Window.Font:SetPoint("TOPLEFT", I.Options.Window, "TOPLEFT", 24, 60)
	I.Options.Window.Font:SetText(ZET.Translation.fontcolor[E.Lang])
	I.Options.Window.Font:SetFontSize(18)
	
	I.Options.Window.SliderFont:SetPoint("TOPLEFT", I.Options.Window.Font, "BOTTOMLEFT", 0, 4)
	I.Options.Window.SliderFont:SetHeight(20)
	I.Options.Window.SliderFont:SetWidth(232)
	I.Options.Window.SliderFont:SetRange(1, 91)
	I.Options.Window.SliderFont:SetPosition(G.SliderC)
	
	I.Options.Window.FontBG:SetPoint("TOPLEFT", I.Options.Window.SliderFont, "TOPLEFT", 0, 20)
	I.Options.Window.FontBG:SetText(ZET.Translation.fontbackground[E.Lang])
	I.Options.Window.FontBG:SetFontSize(18)
	
	I.Options.Window.SliderBG:SetPoint("TOPLEFT", I.Options.Window.FontBG, "BOTTOMLEFT", 0, 4)
	I.Options.Window.SliderBG:SetHeight(20)
	I.Options.Window.SliderBG:SetWidth(232)
	I.Options.Window.SliderBG:SetRange(1, 91)
	I.Options.Window.SliderBG:SetPosition(G.SliderBG)
	
	I.Options.Window.FontSize:SetPoint("TOPLEFT", I.Options.Window.SliderBG, "TOPLEFT", 0, 20)
	I.Options.Window.FontSize:SetText(ZET.Translation.fontsize[E.Lang])
	I.Options.Window.FontSize:SetFontSize(18)
	
	I.Options.Window.SliderSize:SetPoint("TOPLEFT", I.Options.Window.FontSize, "BOTTOMLEFT", 0, 4)
	I.Options.Window.SliderSize:SetHeight(20)
	I.Options.Window.SliderSize:SetWidth(232)
	I.Options.Window.SliderSize:SetRange(8, 72)
	I.Options.Window.SliderSize:SetPosition(G.TextSize)
	
	I.Options.Window.Alpha:SetPoint("TOPLEFT", I.Options.Window.SliderSize, "TOPLEFT", 0, 20)
	I.Options.Window.Alpha:SetText(ZET.Translation.alpha[E.Lang])
	I.Options.Window.Alpha:SetFontSize(18)
	
	I.Options.Window.SliderAlpha:SetPoint("TOPLEFT", I.Options.Window.Alpha, "BOTTOMLEFT", 0, 4)
	I.Options.Window.SliderAlpha:SetHeight(20)
	I.Options.Window.SliderAlpha:SetWidth(232)
	I.Options.Window.SliderAlpha:SetRange(0, 255)
	I.Options.Window.SliderAlpha:SetPosition(math.floor(G.Alpha * 255))
	
	I.Options.Window.Clear:SetPoint("TOPLEFT", I.Options.Window.SliderAlpha, "TOPLEFT", 0, 50)
	I.Options.Window.Clear:SetText(ZET.Translation.clear[E.Lang])
	I.Options.Window.Clear:SetWidth(120)
	
	I.Options.Window.Close:SetPoint("TOPLEFT", I.Options.Window.Clear, "TOPRIGHT", 5, 0)
	I.Options.Window.Close:SetText(ZET.Translation.close[E.Lang])
	I.Options.Window.Close:SetWidth(120)
	
	I.Options.Window.Force:SetPoint("CENTER", I.Options.Window.Close, "BOTTOMLEFT", -5, 20)
	I.Options.Window.Force:SetText(ZET.Translation.force[E.Lang])
	I.Options.Window.Force:SetWidth(140)
	
	-- Mouse Functions
	function I.EventRightClick(Input)
		if Input == "icon" then
			if I.Window == "false" then
				I.Window = "true"
				I.Options.Window:SetVisible(true)
				
			elseif I.Window == "true" then
				I.Window = "false"
				I.Options.Window:SetVisible(false)
				
			else
				I.Window = "true"
				I.Options.Window:SetVisible(true)
			end
		end
	end
	
	function I.EventLeftClick(Input)
		if Input == "clear" then
			for k,v in Pairs(ZET.Interface.Quests) do
					ZET.Interface.Quests[k] = O
					I.Event:SetVisible(false)
				end
			
		elseif Input == "close" then
			I.Window = "false"
			I.Options.Window:SetVisible(false)
			
		elseif Input == "force" then
			I.ForceQL = Inspect.Quest.Detail(Inspect.Quest.List())
			E.Accept(Debug, I.ForceQL)
		end
	end
	
	function I.EventLeftDown(Input)
		if Input == "title" then
			local TMouse = Inspect.Mouse()

			I.Mouse.GlobalX = G.MainX
			I.Mouse.GlobalY = G.MainY
			I.Mouse.MainX = TMouse.x
			I.Mouse.MainY = TMouse.y
			I.Mouse.TLeft = true
			I.Temp.TLeft = true
		elseif Input == "options" then
			local OMouse = Inspect.Mouse()

			I.Mouse.GlobalX = G.IconX
			I.Mouse.GlobalY = G.IconY
			I.Mouse.IconX = OMouse.x
			I.Mouse.IconY = OMouse.y
			I.Mouse.OLeft = true
			I.Temp.OLeft = true
		elseif Input == "window" then
			local WMouse = Inspect.Mouse()

			I.Mouse.GlobalX = G.WindowX
			I.Mouse.GlobalY = G.WindowY
			I.Mouse.WindowX = WMouse.x
			I.Mouse.WindowY = WMouse.y
			I.Mouse.WLeft = true
			I.Temp.WLeft = true
		end
	end
	
	function I.EventRightDown()
		local Mouse = Inspect.Mouse()
		
		I.Mouse.Right = true
		I.Temp.Right = true
	end
	
	function I.EventUp()
		I.Mouse = {}
		I.Temp = {}
	end
	
	function I.EventMouseMove(Input)
		if Input == "title" then
			local TMouse = Inspect.Mouse()
		
			if I.Mouse.TLeft then
				G.MainX = TMouse.x - I.Mouse.MainX + I.Mouse.GlobalX
				G.MainY = TMouse.y - I.Mouse.MainY + I.Mouse.GlobalY
			
				I.Title:SetPoint("CENTER", UIParent, "CENTER", G.MainX, G.MainY)
			end
		elseif Input == "options" then
			local OMouse = Inspect.Mouse()
			
			if I.Mouse.OLeft then
				G.IconX = OMouse.x - I.Mouse.IconX + I.Mouse.GlobalX
				G.IconY = OMouse.y - I.Mouse.IconY + I.Mouse.GlobalY
				
				I.Options:SetPoint("CENTER", UIParent, "CENTER", G.IconX, G.IconY)
			end
		elseif Input == "window" then
			local WMouse = Inspect.Mouse()
			
			if I.Mouse.WLeft then
				G.WindowX = WMouse.x - I.Mouse.WindowX + I.Mouse.GlobalX
				G.WindowY = WMouse.y - I.Mouse.WindowY + I.Mouse.GlobalY
				
				I.Options.Window:SetPoint("CENTER", UIParent, "CENTER", G.WindowX, G.WindowY)
			end
		end
	end
	
	function I.EventSliderChange(Input)
		if Input == "font" then
			for k,v in Pairs(ZET.Colors) do
				if k == I.Options.Window.SliderFont:GetPosition() then
					G.TextColor = k
					G.FontColor[1] = v[1]
					G.FontColor[2] = v[2]
					G.FontColor[3] = v[3]
					G.FontColor[4] = v[4]
					
					I.Title:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
					I.Event:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
				end
			end
			
		elseif Input == "fontbg" then
			for k,v in Pairs(ZET.Colors) do
				if k == I.Options.Window.SliderBG:GetPosition() then
					G.TextBG = k
					G.FontBG[1] = v[1]
					G.FontBG[2] = v[2]
					G.FontBG[3] = v[3]
					
					I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.Alpha)
					I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.Alpha)
				end
			end
			
		elseif Input == "fontsize" then
					G.TextSize = I.Options.Window.SliderSize:GetPosition()
					G.FontSize = G.TextSize
					
					I.Title:SetFontSize(G.TextSize)
					I.Event:SetFontSize(G.TextSize)
		elseif Input == "alpha" then
					G.Alpha = (I.Options.Window.SliderAlpha:GetPosition() / 255)
					G.FontBG[4] = G.Alpha
					
					I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.Alpha)
					I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.Alpha)
		end
	end
	
	-- Mouse Event Functions
	
	function I.Title.Event.LeftDown()
		I.EventLeftDown("title")
	end
	
	function I.Title.Event.RightDown()
		I.EventRightDown()
	end

	function I.Title.Event.LeftUp()
		I.EventUp()
	end	
	
	function I.Title.Event.RightUp()
		I.EventUp()
	end

	function I.Title.Event.MouseMove()
		I.EventMouseMove("title")
	end
	
	function I.Options.Event.RightClick()
		I.EventRightClick("icon")
	end
	
	function I.Options.Event.LeftDown()
		I.EventLeftDown("options")
	end
	
	function I.Options.Event.RightDown()
		I.EventRightDown()
	end

	function I.Options.Event.LeftUp()
		I.EventUp()
	end
	
	function I.Options.Event.RightUp()
		I.EventUp()
	end
	
	function I.Options.Event.MouseMove()
		I.EventMouseMove("options")
	end
	
	function I.Options.Window.Event.LeftDown()
		I.EventLeftDown("window")
	end

	function I.Options.Window.Event.LeftUp()
		I.EventUp()
	end
	
	function I.Options.Window.Event.MouseMove()
		I.EventMouseMove("window")
	end
	
	function I.Options.Window.SliderFont.Event:SliderChange()
		I.EventSliderChange("font")
	end
	
	function I.Options.Window.SliderBG.Event:SliderChange()
		I.EventSliderChange("fontbg")
	end
	
	function I.Options.Window.SliderSize.Event:SliderChange()
		I.EventSliderChange("fontsize")
	end
	
	function I.Options.Window.SliderAlpha.Event:SliderChange()
		I.EventSliderChange("alpha")
	end
	
	function I.Options.Window.Clear.Event:LeftClick()
		I.EventLeftClick("clear")
	end
	
	function I.Options.Window.Close.Event:LeftClick()
		I.EventLeftClick("close")
	end
	
	function I.Options.Window.Force.Event:LeftClick()
		I.EventLeftClick("force")
	end
	
	function I.Title.Event.WheelBack()
		I.MathBR = math.random()
		I.MathBG = math.random()
		I.MathBB = math.random()
		if I.Temp.Left and not I.Temp.Right then
			if G.FontBG[4] <= 0.9 then
				G.FontBG[4] = G.FontBG[4] + 0.1
				I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
				I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
			end
		end
		
		if I.Temp.Right and not I.Temp.Left then
				G.FontColor[1] = I.MathBR
				G.FontColor[2] = I.MathBG
				G.FontColor[3] = I.MathBB
				I.Title:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
				I.Event:SetFontColor(G.FontColor[1],G.FontColor[2],G.FontColor[3],G.FontColor[4])
		end
		
		if not I.Temp.Left and not I.Temp.Right then
			G.FontSize = G.FontSize + 1
			I.Title:SetFontSize(G.FontSize)
			I.Event:SetFontSize(G.FontSize)
		end
	end

	function I.Title.Event.WheelForward()
		I.MathFR = math.random()
		I.MathFG = math.random()
		I.MathFB = math.random()
		if I.Temp.Left and not I.Temp.Right then
			if G.FontBG[4] >= 0.2 then
				G.FontBG[4] = G.FontBG[4] - 0.1
				I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
				I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
			end
		end
		
		if I.Temp.Right and not I.Temp.Left then
				G.FontBG[1] = I.MathFR
				G.FontBG[2] = I.MathFG
				G.FontBG[3] = I.MathFB
				I.Title:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
				I.Event:SetBackgroundColor(G.FontBG[1],G.FontBG[2],G.FontBG[3],G.FontBG[4])
		end
		
		if not I.Temp.Left and not I.Temp.Right then
			G.FontSize = G.FontSize - 1
			I.Title:SetFontSize(G.FontSize)
			I.Event:SetFontSize(G.FontSize)
		end
	end
	
	
	
	function I.Event.Update(Input)		
		local Time = Inspect.Time.Frame()
		
		if E.Data.Time then
			E.Data.Time.Duration = Time - E.Data.Time.Start
		else
			E.Data.Time = {Duration = 0, Start = Time}
		end
		
		if E.Data.Time.Duration - (E.Data.Time.Update or - 2) > 1 then
			I.Text = ""
				for k,v in Pairs(I.Quests) do
					I.Text = String("%0s%0s%0s%0s%0s\n", I.Text, v.Name, v.Action, v.Zone, v.Shard)
					I.Event:SetText(I.Text)
					I.Event:SetVisible(true)
				end
			
			E.Data.Time.Update = E.Data.Time.Duration
		end
	end
	
	Register(Event.System.Update.End, I.Event.Update, "ZET Update")
end